@@ -52,28 +52,56 @@ fi
 shopt -s -q nullglob
 
 # zip up any backups
-for BACKUP in ${BACKUP_BASENAME}-*.tar ; do
+AGGREGATE_EXIT_CODE=0
+for TAR_FILE in ${BACKUP_BASENAME}-*.tar ; do
+
+	BZ2_FILE="${TAR_FILE}.bz2"
 
 	# are the backup and ...
-	TAR_OPEN=`lsof | grep ${BACKUP}`
+	TAR_OPEN=`lsof | grep ${TAR_FILE}`
 	# ... the corresponding bz2 both open at the moment ?
-	BZ2_OPEN=`lsof | grep ${BACKUP}.bz2`
+	BZ2_OPEN=`lsof | grep ${BZ2_FILE}`
 	if test -z "${TAR_OPEN}" -a -z "${BZ2_OPEN}" ; then
 		# no: remove the bz2 and start over compressing
-		rm -f ${BACKUP}.bz2
+		rm -f ${BZ2_FILE}
 	else
 		# yes: skip to next backup
 		continue
 	fi
 
+	# verify tar archive
+	if test -z ${VERIFY_TAR} ; then
+		tar -xOf ${TAR_FILE} > /dev/null
+		RESULT="$?"
+		if test "${RESULT}" != "0" ; then
+			echo "Verifying backup tar archive [${TAR_FILE}] failed (${RESULT}). Skipping."
+			AGGREGATE_EXIT_CODE=${RESULT}
+			continue
+		fi
+	fi
+
+	# compress tar archive
 	# I have tried "xz -9 -e" and it did not make much of
 	# a difference (48 MB in a 1.2 GB backup)
-	bzip2 -zq -${COMPRESSION_LEVEL} ${BACKUP}
-	bzip2 -tq ${BACKUP}.bz2
-	# FIXME: add check for exit code
+	bzip2 -zq -${COMPRESSION_LEVEL} ${TAR_FILE}
+	RESULT="$?"
+	if test "${RESULT}" != "0" ; then
+		echo "Compressing tar archive [${TAR_FILE}] as bz2 failed (${RESULT}). Skipping."
+		AGGREGATE_EXIT_CODE=${RESULT}
+		continue
+	fi
+	# verify compressed archive
+	bzip2 -tq ${BZ2_FILE}
+	RESULT="$?"
+	if test "${RESULT}" != "0" ; then
+		echo "Verifying compressed archive [${BZ2_FILE}] failed (${RESULT}). Removing."
+		AGGREGATE_EXIT_CODE=${RESULT}
+		rm -f ${BZ2_FILE}
+		continue
+	fi
 
-	chmod ${BACKUP_MASK} ${BACKUP}.bz2
-	chown ${BACKUP_OWNER} ${BACKUP}.bz2
+	chmod ${BACKUP_MASK} ${BZ2_FILE}
+	chown ${BACKUP_OWNER} ${BZ2_FILE}
 
 	# Reed-Solomon error protection support
 #	if test -n ${ADD_ECC} ; then
@@ -85,8 +113,8 @@ for BACKUP in ${BACKUP_BASENAME}-*.tar ; do
 		LOCAL_MAILER=`which mail`
 
 		#SHA512="SHA 512:"`sha512sum -b ${BACKUP_FILENAME}.tar.bz2`
-		SHA512=`openssl dgst -sha512 -hex ${BACKUP}.bz2`
-		RMD160=`openssl dgst -ripemd160 -hex ${BACKUP}.bz2`
+		SHA512=`openssl dgst -sha512 -hex ${BZ2_FILE}`
+		RMD160=`openssl dgst -ripemd160 -hex ${BZ2_FILE}`
 
 		export REPLYTO=${SIG_RECEIVER}
 
@@ -98,8 +126,8 @@ for BACKUP in ${BACKUP_BASENAME}-*.tar ; do
 			echo "	<tan>$GNOTARY_TAN</tan>"
 			echo "	<action>notarize</action>"
 			echo "	<hashes number=\"2\">"
-			echo "		<hash file=\"${BACKUP}.bz2\" modified=\"${TS}\" algorithm=\"SHA-512\">${SHA512}</hash>"
-			echo "		<hash file=\"${BACKUP}.bz2\" modified=\"${TS}\" algorithm=\"RIPE-MD-160\">${RMD160}</hash>"
+			echo "		<hash file=\"${BZ2_FILE}\" modified=\"${TS}\" algorithm=\"SHA-512\">${SHA512}</hash>"
+			echo "		<hash file=\"${BZ2_FILE}\" modified=\"${TS}\" algorithm=\"RIPE-MD-160\">${RMD160}</hash>"
 			echo "	</hashes>"
 			echo "</message>"
 			echo " "
@@ -108,6 +136,5 @@ for BACKUP in ${BACKUP_BASENAME}-*.tar ; do
 
 done
 
-exit 0
 
-#==============================================================
+exit ${AGGREGATE_EXIT_CODE}
