@@ -77,6 +77,7 @@ u_up_arrow = u'\u2191'
 u_arrow2right = u'\u2192'						# -->
 u_down_arrow = u'\u2193'
 u_left_arrow_with_tail = u'\u21a2'				# <--<
+u_arrow2right_from_bar = u'\u21a6'				# |->
 u_arrow2right_until_vertical_bar = u'\u21e5'	# -->|
 u_sum = u'\u2211'								# sigma
 u_almost_equal_to = u'\u2248'					# approximately / nearly / roughly
@@ -112,12 +113,14 @@ u_male = u'\u2642'
 u_male_female = u'\u26a5'
 u_checkmark_thin = u'\u2713'
 u_checkmark_thick = u'\u2714'
+u_arrow2right_thick = u'\u2794'
 u_writing_hand = u'\u270d'
 u_pencil_1 = u'\u270e'
 u_pencil_2 = u'\u270f'
 u_pencil_3 = u'\u2710'
 u_latin_cross = u'\u271d'
-u_kanji_yen = u'\u5186'						# Yen kanji
+u_arrow2right_until_black_diamond = u'\u291e'	# ->*
+u_kanji_yen = u'\u5186'							# Yen kanji
 u_replacement_character = u'\ufffd'
 u_link_symbol = u'\u1f517'
 
