@@ -14,10 +14,9 @@ ALTER DATABASE gnumed_v16
 ALTER DATABASE gnumed_v16
 	SET default_transaction_isolation to 'read committed';
 
-ALTER DATABASE gnumed_v16
-	SET sql_inheritance to 'on';
+-- does not exist on PG10 anymore, so can't be set if bootstrapping on PG10
+--ALTER DATABASE gnumed_v16
+--	SET sql_inheritance to 'on';
 
 -- --------------------------------------------------------------
 select gm.log_script_insertion('v16-db-default_settings.sql', 'v16');
-
--- ==============================================================
\ No newline at end of file
